@@ -1,6 +1,6 @@
 /*
   SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,11 +17,11 @@ using namespace KAddressBookImportExport;
 
 ContactSelectionDialog::ContactSelectionDialog(QItemSelectionModel *selectionModel, bool allowToSelectTypeToExport, QWidget *parent)
     : QDialog(parent)
+    , mSelectionWidget(new ContactSelectionWidget(selectionModel, this))
 {
     setWindowTitle(i18nc("@title:window", "Select Contacts"));
     auto mainLayout = new QVBoxLayout(this);
 
-    mSelectionWidget = new ContactSelectionWidget(selectionModel, this);
     if (allowToSelectTypeToExport) {
         mainLayout->addWidget(mSelectionWidget);
         mVCardExport = new ExportSelectionWidget(this);
