@@ -1,6 +1,6 @@
 /*
   SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -75,7 +75,7 @@ Akonadi::Item::List ContactSelectionWidget::selectedItems() const
         qWarning() << " It's a bug here.";
     }
 
-    return Akonadi::Item::List();
+    return {};
 }
 
 ContactList ContactSelectionWidget::selectedContacts() const
@@ -176,7 +176,7 @@ Akonadi::Item::List ContactSelectionWidget::collectAllItems() const
     qApp->processEvents();
 
     if (!job->exec()) {
-        return Akonadi::Item::List();
+        return {};
     }
 
     return job->items();
